Learn R Programming

dafs (version 1.0-38)

plotBoth: Produce postscript and pdf images simulataneously

Description

Produce simulataneous postscript and pdf images using a user defined plot function.

Usage

plotBoth(plotfn, filename, control = plotBoth.control(), ...)

Arguments

plotfn

A function containing the plotting commands

filename

The name of the output file - .eps and .pdf will be appended to the postscript and pdf images respectively

control

The results of plotBoth.control controls font embedding and plotting.

…

Any additional arguments that need to be fed to plotfn

See Also

plotBoth.control

Examples

Run this code
# NOT RUN {
plotBoth(function(){
                    plot(rnorm(100),rnorm(100))}, 'test')
# }

Run the code above in your browser using DataLab